Exception: Pluggy::AuthenticationError

Inherits:
Error
  • Object
show all
Defined in:
lib/pluggy/errors.rb

Overview

POST /auth rejected the client keys (CLIENT_KEYS_UNAUTHORIZED, CLIENT_DISABLED), or an apiKey was rejected and could not be renewed -- either because it survived its one automatic retry, or because the client was built with a static api_key: and has no credentials to renew with.

Instance Attribute Summary

Attributes inherited from Error

#api_message, #code, #code_description, #data, #http_body, #http_headers, #http_status, #json_body

Method Summary

Methods inherited from Error

#initialize, #to_s

Constructor Details

This class inherits a constructor from Pluggy::Error