Exception: Pluggy::ConflictError
- Defined in:
- lib/pluggy/errors.rb
Instance Attribute Summary
Attributes inherited from Error
#api_message, #code, #code_description, #data, #http_body, #http_headers, #http_status, #json_body
Instance Method Summary collapse
-
#duplicate_item_ids ⇒ Object
The ITEM_USER_ALREADY_EXISTS response carries the ids of the items that already exist for this clientUserId (and omits
codeentirely).
Methods inherited from Error
Constructor Details
This class inherits a constructor from Pluggy::Error
Instance Method Details
#duplicate_item_ids ⇒ Object
The ITEM_USER_ALREADY_EXISTS response carries the ids of the items that
already exist for this clientUserId (and omits code entirely).
86 87 88 |
# File 'lib/pluggy/errors.rb', line 86 def duplicate_item_ids json_body&.fetch("items", nil) || [] end |