Class: Pluggy::Resources::BankData
- Inherits:
-
APIResource
- Object
- PluggyObject
- APIResource
- Pluggy::Resources::BankData
- Defined in:
- lib/pluggy/resources/account.rb
Overview
Populated when type == "BANK". Every field is nullable.
Constant Summary
Constants inherited from PluggyObject
PluggyObject::ISO8601, PluggyObject::RESERVED, PluggyObject::TEMPORAL_KEYS
Instance Attribute Summary
Attributes inherited from PluggyObject
Instance Method Summary collapse
-
#overdraft_in_use? ⇒ Boolean
"Cheque especial" -- how much of the arranged overdraft is in use.
Methods inherited from PluggyObject
#==, #[], #as_json, declared_fields, define_field, #each_pair, fields, #hash, #initialize, #inspect, #key?, #keys, #method_missing, nested, nested_types, #read, #respond_to_missing?, #to_h, #to_json, #values
Constructor Details
This class inherits a constructor from Pluggy::PluggyObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Pluggy::PluggyObject
Instance Method Details
#overdraft_in_use? ⇒ Boolean
"Cheque especial" -- how much of the arranged overdraft is in use.
17 |
# File 'lib/pluggy/resources/account.rb', line 17 def overdraft_in_use? = self["overdraftUsedLimit"].to_f.positive? |