Class: Pluggy::Resources::Statement

Inherits:
APIResource show all
Defined in:
lib/pluggy/resources/misc.rb

Overview

GET /accounts/id/statements. The url is a signed link valid for 30 minutes. monthYear is "2024-03", which is why it is deliberately not coerced to a Date.

Constant Summary

Constants inherited from PluggyObject

PluggyObject::ISO8601, PluggyObject::RESERVED, PluggyObject::TEMPORAL_KEYS

Instance Attribute Summary

Attributes inherited from PluggyObject

#client

Method Summary

Methods inherited from PluggyObject

#==, #[], #as_json, declared_fields, define_field, #each_pair, fields, #hash, #initialize, #inspect, #key?, #keys, #method_missing, nested, nested_types, #read, #respond_to_missing?, #to_h, #to_json, #values

Constructor Details

This class inherits a constructor from Pluggy::PluggyObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Pluggy::PluggyObject